@@ -212,7 +212,7 @@
  * AppArmor mount rule encoding
  *
  * TODO:
- *   add semantic checking of options against specified filesytem types
+ *   add semantic checking of options against specified filesystem types
  *   to catch mount options that can't be covered.
  *
  *
@@ -568,7 +568,7 @@ ostream &mnt_rule::dump(ostream &os)
 	else if (allow & AA_MAY_PIVOTROOT)
 		os << "pivotroot";
 	else
-		os << "error: unknonwn mount perm";
+		os << "error: unknown mount perm";
 
 	for (unsigned int i = 0; i < flagsv.size(); i++)
 		os << " flags=(0x" << hex << flagsv[i] << ")";
@@ -819,28 +819,15 @@ int mnt_rule::gen_policy_change_mount_type(Profile &prof, int &count,
 	std::string optsbuf;
 	char class_mount_hdr[64];
 	const char *vec[5];
-	char *mountpoint = mnt_point;
 
 	sprintf(class_mount_hdr, "\\x%02x", AA_CLASS_MOUNT);
 
-	/* change type base rules can specify the mount point by using
-	 * the parser token position reserved to device. that's why if
-	 * the mount point is not specified, we use device in its
-	 * place. this is a deprecated behavior.
-	 *
-	 * change type base rules can not be conditional on device
-	 * (source), device type or data
+	/* change type base rules can not be conditional on device,
+	 * device type or data
 	 */
 	/* rule class single byte header */
 	mntbuf.assign(class_mount_hdr);
-	if (flags && flags != MS_ALL_FLAGS && device && mnt_point) {
-		PERROR("source and mount point cannot be used at the "
-		       "same time for propagation type flags");
-		goto fail;
-	} else if (device && !mnt_point) {
-		mountpoint = device;
-	}
-	if (!convert_entry(mntbuf, mountpoint))
+	if (!convert_entry(mntbuf, mnt_point))
 		goto fail;
 	vec[0] = mntbuf.c_str();
 	/* skip device and type */
@@ -982,7 +969,7 @@ int mnt_rule::gen_flag_rules(Profile &prof, int &count, unsigned int flags,
 		if (!dev_type && !opts &&
 		    gen_policy_bind_mount(prof, count, flags, opt_flags) == RULE_ERROR)
 			return RULE_ERROR;
-		if ((!device || !mnt_point) && !dev_type && !opts &&
+		if (!device && !dev_type && !opts &&
 		    gen_policy_change_mount_type(prof, count, flags, opt_flags) == RULE_ERROR)
 			return RULE_ERROR;
 		if (!dev_type && !opts &&
@@ -998,7 +985,7 @@ int mnt_rule::gen_flag_rules(Profile &prof, int &count, unsigned int flags,
 		return gen_policy_bind_mount(prof, count, flags, opt_flags);
 	} else if ((allow & AA_MAY_MOUNT) &&
 		   (flags & (MS_MAKE_CMDS))
-		   && (!device || !mnt_point) && !dev_type && !opts) {
+		   && !device && !dev_type && !opts) {
 		return gen_policy_change_mount_type(prof, count, flags, opt_flags);
 	} else if ((allow & AA_MAY_MOUNT) && (flags & MS_MOVE)
 		   && !dev_type && !opts) {
