@@ -568,7 +568,7 @@ verify_binary_equality "set rlimit memlock <= 2GB" \
 # Unfortunately we can not just compare an empty profile and hat to a
 # ie. "/t { ^test { /f r, }}"
 # to the second profile with the equivalent rule inserted manually
-# because policy write permission "w" actually expands to mutiple permissions
+# because policy write permission "w" actually expands to multiple permissions
 # under the hood, and the parser is not adding those permissions
 # to the rules it auto generates
 # So we insert the rule with "append" permissions, and rely on the parser
@@ -643,16 +643,6 @@ verify_binary_equality "attachment slash filtering" \
                         @{FOO}=/foo
 			   /t @{BAR}/@{FOO} { }"
 
-# This can potentially fail as ideally it requires a better dfa comparison
-# routine as it can generates hormomorphic dfas. The enumeration of the
-# dfas dumped will be different, even if the binary is the same
-# Note: this test in the future will require -O filter-deny and
-# -O minimize and -O remove-unreachable.
-verify_binary_equality "mount specific deny doesn't affect non-overlapping" \
-			"/t { mount options=bind /e/ -> /**, }" \
-			"/t { audit deny mount /s/** -> /**,
-			      mount options=bind /e/ -> /**, }"
-
 if [ $fails -ne 0 ] || [ $errors -ne 0 ]
 then
 	printf "ERRORS: %d\nFAILS: %d\n" $errors $fails 2>&1
