@@ -15,41 +15,40 @@
 
 import re
 
+from apparmor.common import AppArmorBug, AppArmorException
 from apparmor.regex import RE_PROFILE_NETWORK
-from apparmor.common import AppArmorBug, AppArmorException, type_is_str
 from apparmor.rule import BaseRule, BaseRuleset, logprof_value_or_all, parse_modifiers
-
-# setup module translations
 from apparmor.translations import init_translation
+
 _ = init_translation()
 
+network_domain_keywords = [
+    'unspec', 'unix', 'inet', 'ax25', 'ipx', 'appletalk', 'netrom', 'bridge', 'atmpvc', 'x25', 'inet6',
+    'rose', 'netbeui', 'security', 'key', 'netlink', 'packet', 'ash', 'econet', 'atmsvc', 'rds', 'sna',
+    'irda', 'pppox', 'wanpipe', 'llc', 'ib', 'mpls', 'can', 'tipc', 'bluetooth', 'iucv', 'rxrpc', 'isdn',
+    'phonet', 'ieee802154', 'caif', 'alg', 'nfc', 'vsock', 'kcm', 'qipcrtr', 'smc', 'xdp', 'mctp']
 
-network_domain_keywords   = [ 'unspec', 'unix', 'inet', 'ax25', 'ipx', 'appletalk', 'netrom', 'bridge', 'atmpvc', 'x25', 'inet6',
-                              'rose', 'netbeui', 'security', 'key', 'netlink', 'packet', 'ash', 'econet', 'atmsvc', 'rds', 'sna',
-                              'irda', 'pppox', 'wanpipe', 'llc', 'ib', 'mpls', 'can', 'tipc', 'bluetooth', 'iucv', 'rxrpc', 'isdn',
-                              'phonet', 'ieee802154', 'caif', 'alg', 'nfc', 'vsock', 'kcm', 'qipcrtr', 'smc', 'xdp', 'mctp' ]
-
-network_type_keywords     = ['stream', 'dgram', 'seqpacket', 'rdm', 'raw', 'packet']
+network_type_keywords = ['stream', 'dgram', 'seqpacket', 'rdm', 'raw', 'packet']
 network_protocol_keywords = ['tcp', 'udp', 'icmp']
 
 
-RE_NETWORK_DOMAIN   = '(' + '|'.join(network_domain_keywords) + ')'
-RE_NETWORK_TYPE     = '(' + '|'.join(network_type_keywords) + ')'
+RE_NETWORK_DOMAIN = '(' + '|'.join(network_domain_keywords) + ')'
+RE_NETWORK_TYPE = '(' + '|'.join(network_type_keywords) + ')'
 RE_NETWORK_PROTOCOL = '(' + '|'.join(network_protocol_keywords) + ')'
 
-RE_NETWORK_DETAILS  = re.compile(
-    '^\s*' +
-    '(?P<domain>' + RE_NETWORK_DOMAIN + ')?' +  # optional domain
-    '(\s+(?P<type_or_protocol>' + RE_NETWORK_TYPE + '|' + RE_NETWORK_PROTOCOL + '))?' +  # optional type or protocol
-    '\s*$')
+RE_NETWORK_DETAILS = re.compile(
+    '^\s*'
+    + '(?P<domain>' + RE_NETWORK_DOMAIN + ')?'  # optional domain
+    + '(\s+(?P<type_or_protocol>' + RE_NETWORK_TYPE + '|' + RE_NETWORK_PROTOCOL + '))?'  # optional type or protocol
+    + '\s*$')
 
 
 class NetworkRule(BaseRule):
-    '''Class to handle and store a single network rule'''
+    """Class to handle and store a single network rule"""
 
     # Nothing external should reference this class, all external users
     # should reference the class field NetworkRule.ALL
-    class __NetworkAll(object):
+    class __NetworkAll:
         pass
 
     ALL = __NetworkAll
@@ -59,16 +58,14 @@ class NetworkRule(BaseRule):
     def __init__(self, domain, type_or_protocol, audit=False, deny=False, allow_keyword=False,
                  comment='', log_event=None):
 
-        super(NetworkRule, self).__init__(audit=audit, deny=deny,
-                                             allow_keyword=allow_keyword,
-                                             comment=comment,
-                                             log_event=log_event)
+        super().__init__(audit=audit, deny=deny, allow_keyword=allow_keyword,
+                         comment=comment, log_event=log_event)
 
         self.domain = None
         self.all_domains = False
         if domain == NetworkRule.ALL:
             self.all_domains = True
-        elif type_is_str(domain):
+        elif type(domain) is str:
             if domain in network_domain_keywords:
                 self.domain = domain
             else:
@@ -80,7 +77,7 @@ class NetworkRule(BaseRule):
         self.all_type_or_protocols = False
         if type_or_protocol == NetworkRule.ALL:
             self.all_type_or_protocols = True
-        elif type_is_str(type_or_protocol):
+        elif type(type_or_protocol) is str:
             if type_or_protocol in network_protocol_keywords:
                 self.type_or_protocol = type_or_protocol
             elif type_or_protocol in network_type_keywords:
@@ -96,7 +93,7 @@ class NetworkRule(BaseRule):
 
     @classmethod
     def _parse(cls, raw_rule):
-        '''parse raw_rule and return NetworkRule'''
+        """parse raw_rule and return NetworkRule"""
 
         matches = cls._match(raw_rule)
         if not matches:
@@ -130,7 +127,7 @@ class NetworkRule(BaseRule):
                            audit=audit, deny=deny, allow_keyword=allow_keyword, comment=comment)
 
     def get_clean(self, depth=0):
-        '''return rule (in clean/default formatting)'''
+        """return rule (in clean/default formatting)"""
 
         space = '  ' * depth
 
@@ -148,10 +145,10 @@ class NetworkRule(BaseRule):
         else:
             raise AppArmorBug('Empty type or protocol in network rule')
 
-        return('%s%snetwork%s%s,%s' % (space, self.modifiers_str(), domain, type_or_protocol, self.comment))
+        return ('%s%snetwork%s%s,%s' % (space, self.modifiers_str(), domain, type_or_protocol, self.comment))
 
     def is_covered_localvars(self, other_rule):
-        '''check if other_rule is covered by this rule object'''
+        """check if other_rule is covered by this rule object"""
 
         if not self._is_covered_plain(self.domain, self.all_domains, other_rule.domain, other_rule.all_domains, 'domain'):
             return False
@@ -163,7 +160,7 @@ class NetworkRule(BaseRule):
         return True
 
     def is_equal_localvars(self, rule_obj, strict):
-        '''compare if rule-specific variables are equal'''
+        """compare if rule-specific variables are equal"""
 
         if not type(rule_obj) == NetworkRule:
             raise AppArmorBug('Passed non-network rule: %s' % str(rule_obj))
@@ -179,19 +176,19 @@ class NetworkRule(BaseRule):
         return True
 
     def logprof_header_localvars(self):
-        family      = logprof_value_or_all(self.domain,             self.all_domains)
-        sock_type   = logprof_value_or_all(self.type_or_protocol,   self.all_type_or_protocols)
+        family    = logprof_value_or_all(self.domain,           self.all_domains)  # noqa: E221
+        sock_type = logprof_value_or_all(self.type_or_protocol, self.all_type_or_protocols)
 
         return [
             _('Network Family'), family,
-            _('Socket Type'),    sock_type,
+            _('Socket Type'), sock_type,
         ]
 
 
 class NetworkRuleset(BaseRuleset):
-    '''Class to handle and store a collection of network rules'''
+    """Class to handle and store a collection of network rules"""
 
     def get_glob(self, path_or_rule):
-        '''Return the next possible glob. For network rules, that's "network DOMAIN," or "network," (all network)'''
+        """Return the next possible glob. For network rules, that's "network DOMAIN," or "network," (all network)"""
         # XXX return 'network DOMAIN,' if 'network DOMAIN TYPE_OR_PROTOCOL' was given
         return 'network,'
