@@ -8,8 +8,6 @@
 #
 # ------------------------------------------------------------------
 
-from apparmor.common import AppArmorException, debug, error, msg, cmd
-import apparmor.easyprof
 import optparse
 import os
 import pwd
@@ -17,30 +15,37 @@ import re
 import signal
 import socket
 import sys
-import tempfile
 import time
+from shutil import which
+from tempfile import NamedTemporaryFile
+
+import apparmor.easyprof
+from apparmor.common import AppArmorException, cmd, debug, error, msg
+
 
 def check_requirements(binary):
-    '''Verify necessary software is installed'''
-    exes = ['xset',        # for detecting free X display
-            'aa-easyprof', # for templates
-            'aa-exec',     # for changing profile
-            'sudo',        # eventually get rid of this
-            'pkexec',      # eventually get rid of this
-            binary]
+    """Verify necessary software is installed"""
+    exes = [
+        'xset',         # for detecting free X display
+        'aa-easyprof',  # for templates
+        'aa-exec',      # for changing profile
+        'sudo',         # eventually get rid of this
+        'pkexec',       # eventually get rid of this
+        binary
+    ]
 
     for e in exes:
         debug("Searching for '%s'" % e)
-        rc, report = cmd(['which', e])
-        if rc != 0:
+        if which(e) is None:
             error("Could not find '%s'" % e, do_exit=False)
             return False
 
     return True
 
+
 def parse_args(args=None, parser=None):
-    '''Parse arguments'''
-    if parser == None:
+    """Parse arguments"""
+    if parser is None:
         parser = optparse.OptionParser()
 
     parser.add_option('-X', '--with-x',
@@ -81,8 +86,8 @@ def parse_args(args=None, parser=None):
 
     valid_xservers = ['xpra', 'xpra3d', 'xephyr']
     if my_opt.withx and my_opt.xserver.lower() not in valid_xservers:
-            error("Invalid server '%s'. Use one of: %s" % (my_opt.xserver, \
-                                                           ", ".join(valid_xservers)))
+        error("Invalid server '%s'. Use one of: %s"
+              % (my_opt.xserver, ", ".join(valid_xservers)))
 
     if my_opt.withx:
         if my_opt.xephyr_geometry and my_opt.xserver.lower() != "xephyr":
@@ -98,21 +103,21 @@ def parse_args(args=None, parser=None):
 
     return (my_opt, my_args)
 
+
 def gen_policy_name(binary):
-    '''Generate a temporary policy based on the binary name'''
-    return "sandbox-%s%s" % (pwd.getpwuid(os.geteuid())[0],
-                              re.sub(r'/', '_', binary))
+    """Generate a temporary policy based on the binary name"""
+    return "sandbox-%s%s" % (pwd.getpwuid(os.geteuid())[0], re.sub(r'/', '_', binary))
+
 
 def set_environ(env):
-    keys = env.keys()
-    keys.sort()
-    for k in keys:
-        msg("Using: %s=%s" % (k, env[k]))
-        os.environ[k] = env[k]
+    for k, v in sorted(env.items()):
+        msg("Using: {}={}".format(k, v))
+        os.environ[k] = v
 
-def aa_exec(command, opt, environ={}, verify_rules=[]):
-    '''Execute binary under specified policy'''
-    if opt.profile != None:
+
+def aa_exec(command, opt, environ=None, verify_rules=()):
+    """Execute binary under specified policy"""
+    if opt.profile is not None:
         policy_name = opt.profile
     else:
         opt.ensure_value("template_var", None)
@@ -128,25 +133,21 @@ def aa_exec(command, opt, environ={}, verify_rules=[]):
         policy = easyp.gen_policy(**params)
         debug("\n%s" % policy)
 
-        tmp = tempfile.NamedTemporaryFile(prefix = '%s-' % policy_name)
-        if sys.version_info[0] >= 3:
-            tmp.write(bytes(policy, 'utf-8'))
-        else:
-            tmp.write(policy)
-        tmp.flush()
+        with NamedTemporaryFile(prefix='%s-' % policy_name) as tmp:
+            tmp.write(policy.encode('utf-8'))
 
-        debug("using '%s' template" % opt.template)
-        # TODO: get rid of this
-        if opt.withx:
-            rc, report = cmd(['pkexec', 'apparmor_parser', '-r', '%s' % tmp.name])
-        else:
-            rc, report = cmd(['sudo', 'apparmor_parser', '-r', tmp.name])
-        if rc != 0:
-            raise AppArmorException("Could not load policy")
+            debug("using '%s' template" % opt.template)
+            # TODO: get rid of this
+            if opt.withx:
+                rc, report = cmd(('pkexec', 'apparmor_parser', '-r', '%s' % tmp.name))
+            else:
+                rc, report = cmd(('sudo', 'apparmor_parser', '-r', tmp.name))
+            if rc != 0:
+                raise AppArmorException("Could not load policy")
 
-        rc, report = cmd(['sudo', 'apparmor_parser', '-p', tmp.name])
-        if rc != 0:
-            raise AppArmorException("Could not dump policy")
+            rc, report = cmd(('sudo', 'apparmor_parser', '-p', tmp.name))
+            if rc != 0:
+                raise AppArmorException("Could not dump policy")
 
         # Make sure the dynamic profile has the appropriate line for X
         for r in verify_rules:
@@ -159,34 +160,35 @@ def aa_exec(command, opt, environ={}, verify_rules=[]):
             if not found:
                 raise AppArmorException("Could not find required rule: %s" % r)
 
-    set_environ(environ)
-    args = ['aa-exec', '-p', policy_name, '--'] + command
+    if environ:
+        set_environ(environ)
+    args = ['aa-exec', '-p', policy_name, '--']
+    args.extend(command)
     rc, report = cmd(args)
     return rc, report
 
+
 def run_sandbox(command, opt):
-    '''Run application'''
+    """Run application"""
     # aa-exec
     rc, report = aa_exec(command, opt)
     return rc, report
 
+
 class SandboxXserver():
-    def __init__(self, title, geometry=None,
-                              driver=None,
-                              xauth=None,
-                              clipboard=False):
+    def __init__(self, title, geometry=None, driver=None, xauth=None, clipboard=False):
         self.geometry = geometry
         self.title = title
         self.pids = []
         self.driver = driver
         self.clipboard = clipboard
         self.tempfiles = []
-        self.timeout = 5 # used by xauth and for server starts
+        self.timeout = 5  # used by xauth and for server starts
 
         # preserve our environment
         self.old_environ = dict()
-        for env in ['DISPLAY', 'XAUTHORITY', 'UBUNTU_MENUPROXY',
-                    'QT_X11_NO_NATIVE_MENUBAR', 'LIBOVERLAY_SCROLLBAR']:
+        for env in ('DISPLAY', 'XAUTHORITY', 'UBUNTU_MENUPROXY',
+                    'QT_X11_NO_NATIVE_MENUBAR', 'LIBOVERLAY_SCROLLBAR'):
             if env in os.environ:
                 self.old_environ[env] = os.environ[env]
 
@@ -207,7 +209,7 @@ class SandboxXserver():
         self.new_environ["LIBOVERLAY_SCROLLBAR"] = "0"
 
     def cleanup(self):
-        '''Cleanup our forked pids, reset the environment, etc'''
+        """Cleanup our forked pids, reset the environment, etc"""
         self.pids.reverse()
         debug(self.pids)
         for pid in self.pids:
@@ -231,7 +233,7 @@ class SandboxXserver():
         set_environ(self.old_environ)
 
     def find_free_x_display(self):
-        '''Find a free X display'''
+        """Find a free X display"""
         old_lang = None
         if 'LANG' in os.environ:
             old_lang = os.environ['LANG']
@@ -239,11 +241,10 @@ class SandboxXserver():
 
         display = ""
         current = self.old_environ["DISPLAY"]
-        for i in range(1,257): # TODO: this puts an artificial limit of 256
-                               #       sandboxed applications
+        for i in range(1, 257):  # TODO: this puts an artificial limit of 256 sandboxed applications
             tmp = ":%d" % i
             os.environ["DISPLAY"] = tmp
-            rc, report = cmd(['xset', '-q'])
+            rc, report = cmd(('xset', '-q'))
             if rc != 0 and 'Invalid MIT-MAGIC-COOKIE-1' not in report:
                 display = tmp
                 break
@@ -252,11 +253,11 @@ class SandboxXserver():
             os.environ['LANG'] = old_lang
 
         os.environ["DISPLAY"] = current
-        if display == "":
+        if not display:
             raise AppArmorException("Could not find available X display")
 
         # Use dedicated .Xauthority file
-        xauth = os.path.join(os.path.expanduser('~'), \
+        xauth = os.path.join(os.path.expanduser('~'),
                              '.Xauthority-sandbox%s' % display.split(':')[1])
 
         return display, xauth
@@ -265,13 +266,13 @@ class SandboxXserver():
         return "(Sandbox%s) %s" % (self.display, self.title)
 
     def verify_host_setup(self):
-        '''Make sure we have everything we need'''
+        """Make sure we have everything we need"""
         old_lang = None
         if 'LANG' in os.environ:
             old_lang = os.environ['LANG']
 
         os.environ['LANG'] = 'C'
-        rc, report = cmd(['xhost'])
+        rc, report = cmd(('xhost',))
 
         if old_lang:
             os.environ['LANG'] = old_lang
@@ -285,59 +286,63 @@ class SandboxXserver():
             raise AppArmorException("Access control allows '%s' full access. Please see 'man aa-sandbox' for details" % username)
 
     def start(self):
-        '''Start a nested X server (need to override)'''
+        """Start a nested X server (need to override)"""
         # clean up the old one
         if os.path.exists(self.xauth):
             os.unlink(self.xauth)
-        rc, cookie = cmd(['mcookie'])
+        rc, cookie = cmd(('mcookie',))
         if rc != 0:
             raise AppArmorException("Could not generate magic cookie")
 
-        rc, out = cmd(['xauth', '-f', self.xauth, \
-                       'add', \
-                       self.display, \
-                       'MIT-MAGIC-COOKIE-1', \
-                       cookie.strip()])
+        rc, out = cmd(
+            ('xauth', '-f', self.xauth,
+             'add',
+             self.display,
+             'MIT-MAGIC-COOKIE-1',
+             cookie.strip())
+        )
         if rc != 0:
             raise AppArmorException("Could not generate '%s'" % self.display)
 
 
 class SandboxXephyr(SandboxXserver):
     def start(self):
-        for e in ['Xephyr', 'matchbox-window-manager']:
+        for e in ('Xephyr', 'matchbox-window-manager'):
             debug("Searching for '%s'" % e)
-            rc, report = cmd(['which', e])
-            if rc != 0:
+            if which(e) is None:
                 raise AppArmorException("Could not find '%s'" % e)
 
-        '''Run any setup code'''
+        # Run any setup code
         SandboxXserver.start(self)
 
-        '''Start a Xephyr server'''
+        # Start a Xephyr server
         listener_x = os.fork()
         if listener_x == 0:
             # TODO: break into config file? Which are needed?
-            x_exts = ['-extension', 'GLX',
-                      '-extension', 'MIT-SHM',
-                      '-extension', 'RENDER',
-                      '-extension', 'SECURITY',
-                      '-extension', 'DAMAGE'
-                     ]
+            x_exts = [
+                '-extension', 'GLX',
+                '-extension', 'MIT-SHM',
+                '-extension', 'RENDER',
+                '-extension', 'SECURITY',
+                '-extension', 'DAMAGE'
+            ]
             # verify_these
-            x_extra_args = ['-host-cursor', # less secure?
-                            '-fakexa',      # for games? seems not needed
-                            '-nodri',       # more secure?
-                           ]
+            x_extra_args = [
+                '-host-cursor',  # less secure?
+                '-fakexa',  # for games? seems not needed
+                '-nodri',  # more secure?
+            ]
 
             if not self.geometry:
                 self.geometry = "640x480"
-            x_args = ['-nolisten', 'tcp',
-                      '-screen', self.geometry,
-                      '-br',        # black background
-                      '-reset',     # reset after last client exists
-                      '-terminate', # terminate at server reset
-                      '-title', self.generate_title(),
-                      ] + x_exts + x_extra_args
+            x_args = [
+                '-nolisten', 'tcp',
+                '-screen', self.geometry,
+                '-br',  # black background
+                '-reset',  # reset after last client exists
+                '-terminate',  # terminate at server reset
+                '-title', self.generate_title(),
+            ] + x_exts + x_extra_args
 
             args = ['/usr/bin/Xephyr'] + x_args + [self.display]
             debug(" ".join(args))
@@ -345,7 +350,7 @@ class SandboxXephyr(SandboxXserver):
             sys.exit(0)
         self.pids.append(listener_x)
 
-        time.sleep(1) # FIXME: detect if running
+        time.sleep(1)  # FIXME: detect if running
 
         # Next, start the window manager
         sys.stdout.flush()
@@ -361,7 +366,7 @@ class SandboxXephyr(SandboxXserver):
             sys.exit(0)
 
         self.pids.append(listener_wm)
-        time.sleep(1) # FIXME: detect if running
+        time.sleep(1)  # FIXME: detect if running
 
 
 class SandboxXpra(SandboxXserver):
@@ -377,7 +382,7 @@ class SandboxXpra(SandboxXserver):
 
         # Annoyingly, xpra doesn't clean up itself well if the application
         # failed for some reason. Try to account for that.
-        rc, report = cmd(['ps', 'auxww'])
+        rc, report = cmd(('ps', 'auxww'))
         for line in report.splitlines():
             if '-for-Xpra-%s' % self.display in line:
                 self.pids.append(int(line.split()[1]))
@@ -385,7 +390,7 @@ class SandboxXpra(SandboxXserver):
         SandboxXserver.cleanup(self)
 
     def _get_xvfb_args(self):
-        '''Setup xvfb arguments'''
+        """Setup xvfb arguments"""
         # Debugging tip (can also use glxinfo):
         # $ xdpyinfo > /tmp/native
         # $ aa-sandbox -X -t sandbox-x /usr/bin/xdpyinfo > /tmp/nested
@@ -393,7 +398,7 @@ class SandboxXpra(SandboxXserver):
 
         xvfb_args = []
 
-        if self.driver == None:
+        if self.driver is None:
             # The default from the man page, but be explicit in what we enable
             xvfb_args.append('--xvfb=Xvfb')
             xvfb_args.append('-screen 0 3840x2560x24+32')
@@ -541,25 +546,20 @@ Section "ServerLayout"
   InputDevice  "NoKeyboard"
 EndSection
 '''
-
-            tmp, xorg_conf = tempfile.mkstemp(prefix='aa-sandbox-xorg.conf-')
-            self.tempfiles.append(xorg_conf)
-            if sys.version_info[0] >= 3:
-                os.write(tmp, bytes(conf, 'utf-8'))
-            else:
-                os.write(tmp, conf)
-            os.close(tmp)
+            with NamedTemporaryFile('wb', prefix='aa-sandbox-xorg.conf-', delete=False) as tmp:
+                self.tempfiles.append(tmp.name)
+                tmp.write(conf.encode('utf-8'))
 
             xvfb_args.append('--xvfb=Xorg')
-            xvfb_args.append('-dpi 96') # https://www.xpra.org/trac/ticket/163
+            xvfb_args.append('-dpi 96')  # https://www.xpra.org/trac/ticket/163
             xvfb_args.append('-nolisten tcp')
             xvfb_args.append('-noreset')
             xvfb_args.append('-logfile %s' % os.path.expanduser('~/.xpra/%s.log' % self.display))
             xvfb_args.append('-auth %s' % self.new_environ['XAUTHORITY'])
-            xvfb_args.append('-config %s' % xorg_conf)
-            extensions = ['Composite', 'GLX', 'RANDR', 'RENDER', 'SECURITY']
-            for i in extensions:
-                xvfb_args.append('+extension %s' % i)
+            xvfb_args.append('-config %s' % tmp.name)
+            xvfb_args.extend(
+                '+extension %s' % i for i in ('Composite', 'GLX', 'RANDR', 'RENDER', 'SECURITY')
+            )
         else:
             raise AppArmorException("Unsupported X driver '%s'" % self.driver)
 
@@ -567,8 +567,7 @@ EndSection
 
     def start(self):
         debug("Searching for '%s'" % 'xpra')
-        rc, report = cmd(['which', 'xpra'])
-        if rc != 0:
+        if which('xpra') is None:
             raise AppArmorException("Could not find '%s'" % 'xpra')
 
         if self.driver == "xdummy":
@@ -578,7 +577,7 @@ EndSection
             if not os.path.exists(drv):
                 raise AppArmorException("Could not find '%s'" % drv)
 
-        '''Run any setup code'''
+        # Run any setup code
         SandboxXserver.start(self)
 
         xvfb_args = self._get_xvfb_args()
@@ -587,10 +586,10 @@ EndSection
             os.environ['XAUTHORITY'] = self.xauth
 
             # This will clean out any dead sessions
-            cmd(['xpra', 'list'])
+            cmd(('xpra', 'list'))
 
             x_args = ['--no-daemon',
-                      #'--no-mmap', # for security?
+                      # '--no-mmap', # for security?
                       '--no-pulseaudio']
             if not self.clipboard:
                 x_args.append('--no-clipboard')
@@ -608,9 +607,9 @@ EndSection
         started = False
 
         # We need to wait for the xpra socket to exist before attaching
-        fn = os.path.join(os.environ['HOME'], '.xpra', '%s-%s' % \
-                          (socket.gethostname(), self.display.split(':')[1]))
-        for i in range(self.timeout * 2): # up to self.timeout seconds to start
+        fn = os.path.join(os.environ['HOME'], '.xpra', '%s-%s'
+                          % (socket.gethostname(), self.display.split(':')[1]))
+        for i in range(self.timeout * 2):  # up to self.timeout seconds to start
             if os.path.exists(fn):
                 debug("Found '%s'! Proceeding to attach" % fn)
                 break
@@ -622,8 +621,8 @@ EndSection
             self.cleanup()
             raise AppArmorException("Could not start xpra (try again with -d)")
 
-        for i in range(self.timeout): # Up to self.timeout seconds to start
-            rc, out = cmd(['xpra', 'list'])
+        for i in range(self.timeout):  # Up to self.timeout seconds to start
+            rc, out = cmd(('xpra', 'list'))
 
             if 'DEAD session at %s' % self.display in out:
                 error("xpra session at '%s' died" % self.display, do_exit=False)
@@ -649,7 +648,7 @@ EndSection
         if listener_attach == 0:
             args = ['/usr/bin/xpra', 'attach', self.display,
                                      '--title=%s' % self.generate_title(),
-                                     #'--no-mmap', # for security?
+                                     # '--no-mmap', # for security?
                                      '--no-tray',
                                      '--no-pulseaudio']
             if not self.clipboard:
@@ -663,9 +662,9 @@ EndSection
         self.pids.append(listener_attach)
 
         # Make sure that a client has attached
-        for i in range(self.timeout): # up to self.timeout seconds to attach
+        for i in range(self.timeout):  # up to self.timeout seconds to attach
             time.sleep(1)
-            rc, out = cmd (['xpra', 'info', self.display])
+            rc, out = cmd(('xpra', 'info', self.display))
             search = 'clients=1'
             if search in out:
                 debug("Client successfully attached!")
@@ -677,22 +676,19 @@ EndSection
 
 
 def run_xsandbox(command, opt):
-    '''Run X application in a sandbox'''
+    """Run X application in a sandbox"""
     old_cwd = os.getcwd()
 
     # first, start X
     if opt.xserver.lower() == "xephyr":
-        x = SandboxXephyr(command[0], geometry=opt.xephyr_geometry,
-                                      xauth=opt.xauthority)
+        x = SandboxXephyr(command[0], geometry=opt.xephyr_geometry, xauth=opt.xauthority)
     elif opt.xserver.lower() == "xpra3d":
-        x = SandboxXpra(command[0], geometry=None,
-                                    driver="xdummy",
-                                    xauth=opt.xauthority,
-                                    clipboard=opt.with_clipboard)
+        x = SandboxXpra(
+            command[0], geometry=None, driver="xdummy", xauth=opt.xauthority,
+            clipboard=opt.with_clipboard)
     else:
-        x = SandboxXpra(command[0], geometry=None,
-                                    xauth=opt.xauthority,
-                                    clipboard=opt.with_clipboard)
+        x = SandboxXpra(
+            command[0], geometry=None, xauth=opt.xauthority, clipboard=opt.with_clipboard)
 
     x.verify_host_setup()
 
@@ -700,7 +696,7 @@ def run_xsandbox(command, opt):
     keys = x.old_environ.keys()
     keys.sort()
     for k in keys:
-        debug ("Old: %s=%s" % (k, x.old_environ[k]))
+        debug("Old: %s=%s" % (k, x.old_environ[k]))
 
     try:
         x.start()
