@@ -1,6 +1,6 @@
 # ----------------------------------------------------------------------
 #    Copyright (C) 2013 Kshitij Gupta <kgupta8592@gmail.com>
-#    Copyright (C) 2015-2018 Christian Boltz <apparmor@cboltz.de>
+#    Copyright (C) 2015-2022 Christian Boltz <apparmor@cboltz.de>
 #
 #    This program is free software; you can redistribute it and/or
 #    modify it under the terms of version 2 of the GNU General Public
@@ -14,26 +14,29 @@
 # ----------------------------------------------------------------------
 import os
 import sys
+from shutil import which
 
 import apparmor.aa as apparmor
 import apparmor.ui as aaui
-from apparmor.common import user_perm, cmd
-
-# setup module translations
+from apparmor.common import AppArmorException, cmd, is_skippable_file, user_perm
 from apparmor.translations import init_translation
+
 _ = init_translation()
 
+
 class aa_tools:
     def __init__(self, tool_name, args):
-        apparmor.init_aa(profiledir=args.dir)
+        apparmor.init_aa(profiledir=args.dir, confdir=args.configdir)
+
+        if not user_perm(apparmor.profile_dir):
+            raise AppArmorException("Cannot write to profile directory: %s" % (apparmor.profile_dir))
 
         self.name = tool_name
         self.profiling = args.program
-        self.check_profile_dir()
         self.silent = None
         self.do_reload = args.do_reload
 
-        if tool_name in ['audit']:
+        if tool_name == 'audit':
             self.remove = args.remove
         elif tool_name == 'autodep':
             self.force = args.force
@@ -41,12 +44,8 @@ class aa_tools:
         elif tool_name == 'cleanprof':
             self.silent = args.silent
 
-    def check_profile_dir(self):
-        if not user_perm(apparmor.profile_dir):
-            raise apparmor.AppArmorException("Cannot write to profile directory: %s" % (apparmor.profile_dir))
-
     def get_next_to_profile(self):
-        '''Iterator function to walk the list of arguments passed'''
+        """Iterator function to walk the list of arguments passed"""
 
         for p in self.profiling:
             if not p:
@@ -61,30 +60,19 @@ class aa_tools:
                     profile = fq_path
                 else:
                     program = fq_path
-                    if self.name == 'cleanprof':
-                        profile = apparmor.active_profiles.profile_from_attachment(fq_path)
-                    else:
-                        profile = apparmor.get_profile_filename_from_attachment(fq_path, True)
+                    profile = apparmor.get_profile_filename_from_attachment(fq_path, True)
             else:
-                which = apparmor.which(p)
-                if self.name == 'cleanprof' and p in apparmor.aa:
-                    program = p  # not really correct, but works
-                    profile = p
-                elif which is not None:
-                    program = apparmor.get_full_path(which)
-                    if self.name == 'cleanprof':
-                        profile = program
-                    else:
-                        profile = apparmor.get_profile_filename_from_attachment(program, True)
+                which_ = which(p)
+                if which_ is not None:
+                    program = apparmor.get_full_path(which_)
+                    profile = apparmor.get_profile_filename_from_attachment(program, True)
                 elif os.path.exists(os.path.join(apparmor.profile_dir, p)):
                     program = None
-                    if self.name == 'cleanprof':
-                        profile = p
-                    else:
-                        profile = apparmor.get_full_path(os.path.join(apparmor.profile_dir, p)).strip()
+                    profile = apparmor.get_full_path(os.path.join(apparmor.profile_dir, p)).strip()
                 else:
                     if '/' not in p:
-                        aaui.UI_Info(_("Can't find %(program)s in the system path list. If the name of the application\nis correct, please run 'which %(program)s' as a user with correct PATH\nenvironment set up in order to find the fully-qualified path and\nuse the full path as parameter.") % { 'program': p })
+                        aaui.UI_Info(_("Can't find %(program)s in the system path list. If the name of the application\nis correct, please run 'which %(program)s' as a user with correct PATH\nenvironment set up in order to find the fully-qualified path and\nuse the full path as parameter.")
+                                     % {'program': p})
                     else:
                         aaui.UI_Info(_("%s does not exist, please double-check the path.") % p)
                     continue
@@ -99,19 +87,20 @@ class aa_tools:
             if program is None:
                 program = profile
 
-            if not program or not(os.path.exists(program) or profile in apparmor.aa):
+            if not program or not(os.path.exists(program) or apparmor.profile_exists(program)):
                 if program and not program.startswith('/'):
                     program = aaui.UI_GetString(_('The given program cannot be found, please try with the fully qualified path name of the program: '), '')
                 else:
                     aaui.UI_Info(_("%s does not exist, please double-check the path.") % program)
                     sys.exit(1)
 
-            if program and profile in apparmor.aa:
-                self.clean_profile(program, profile)
+            if program and apparmor.profile_exists(program):
+                self.clean_profile(program)
 
             else:
                 if '/' not in program:
-                    aaui.UI_Info(_("Can't find %(program)s in the system path list. If the name of the application\nis correct, please run 'which %(program)s' as a user with correct PATH\nenvironment set up in order to find the fully-qualified path and\nuse the full path as parameter.") % { 'program': program })
+                    aaui.UI_Info(_("Can't find %(program)s in the system path list. If the name of the application\nis correct, please run 'which %(program)s' as a user with correct PATH\nenvironment set up in order to find the fully-qualified path and\nuse the full path as parameter.")
+                                 % {'program': program})
                 else:
                     aaui.UI_Info(_("%s does not exist, please double-check the path.") % program)
                     sys.exit(1)
@@ -123,7 +112,7 @@ class aa_tools:
 
             output_name = profile if program is None else program
 
-            if not os.path.isfile(profile) or apparmor.is_skippable_file(profile):
+            if not os.path.isfile(profile) or is_skippable_file(profile):
                 aaui.UI_Info(_('Profile for %s not found, skipping') % output_name)
                 continue
 
@@ -139,7 +128,7 @@ class aa_tools:
 
             output_name = profile if program is None else program
 
-            if not os.path.isfile(profile) or apparmor.is_skippable_file(profile):
+            if not os.path.isfile(profile) or is_skippable_file(profile):
                 aaui.UI_Info(_('Profile for %s not found, skipping') % output_name)
                 continue
 
@@ -154,7 +143,7 @@ class aa_tools:
 
             output_name = profile if program is None else program
 
-            if not os.path.isfile(profile) or apparmor.is_skippable_file(profile):
+            if not os.path.isfile(profile) or is_skippable_file(profile):
                 aaui.UI_Info(_('Profile for %s not found, skipping') % output_name)
                 continue
 
@@ -169,7 +158,7 @@ class aa_tools:
 
             output_name = profile if program is None else program
 
-            if not os.path.isfile(profile) or apparmor.is_skippable_file(profile):
+            if not os.path.isfile(profile) or is_skippable_file(profile):
                 aaui.UI_Info(_('Profile for %s not found, skipping') % output_name)
                 continue
 
@@ -205,20 +194,20 @@ class aa_tools:
                 if self.aa_mountpoint:
                     apparmor.reload(program)
 
-    def clean_profile(self, program, profile):
-        filename = apparmor.get_profile_filename_from_profile_name(profile)
+    def clean_profile(self, program):
+        filename = apparmor.get_profile_filename_from_attachment(program, True)
         import apparmor.cleanprofile as cleanprofile
         prof = cleanprofile.Prof(filename)
         cleanprof = cleanprofile.CleanProf(True, prof, prof)
-        deleted = cleanprof.remove_duplicate_rules(profile)
+        deleted = cleanprof.remove_duplicate_rules(program)
         aaui.UI_Info(_("\nDeleted %s rules.") % deleted)
-        apparmor.changed[profile] = True
+        apparmor.changed[program] = True
 
         if filename:
             if not self.silent:
                 q = aaui.PromptQuestion()
                 q.title = 'Changed Local Profiles'
-                q.explanation = _('The local profile for %(program)s in file %(file)s was changed. Would you like to save it?') % { 'program': program, 'file': filename }
+                q.explanation = _('The local profile for %(program)s in file %(file)s was changed. Would you like to save it?') % {'program': program, 'file': filename}
                 q.functions = ['CMD_SAVE_CHANGES', 'CMD_VIEW_CHANGES', 'CMD_ABORT']
                 q.default = 'CMD_VIEW_CHANGES'
                 q.options = []
@@ -228,17 +217,17 @@ class aa_tools:
                 while ans != 'CMD_SAVE_CHANGES':
                     ans, arg = q.promptUser()
                     if ans == 'CMD_SAVE_CHANGES':
-                        apparmor.write_profile_ui_feedback(profile)
+                        apparmor.write_profile_ui_feedback(program, True)
                         self.reload_profile(filename)
                     elif ans == 'CMD_VIEW_CHANGES':
-                        #oldprofile = apparmor.serialize_profile(apparmor.original_aa[profile], program, {})
-                        newprofile = apparmor.serialize_profile(apparmor.aa[profile], profile, {})  #  {'is_attachment': True})
+                        # oldprofile = apparmor.serialize_profile(apparmor.split_to_merged(apparmor.original_aa), program, {})
+                        newprofile = apparmor.serialize_profile(apparmor.split_to_merged(apparmor.aa), program, {'is_attachment': True})
                         aaui.UI_Changes(filename, newprofile, comments=True)
             else:
-                apparmor.write_profile_ui_feedback(profile, True)
+                apparmor.write_profile_ui_feedback(program, True)
                 self.reload_profile(filename)
         else:
-            raise apparmor.AppArmorException(_('The profile for %s does not exists. Nothing to clean.') % program)
+            raise AppArmorException(_('The profile for %s does not exists. Nothing to clean.') % program)
 
     def enable_profile(self, filename):
         apparmor.delete_symlink('disable', filename)
@@ -254,13 +243,10 @@ class aa_tools:
         cmd_info = cmd([apparmor.parser, '-I%s' % apparmor.profile_dir, '--base', apparmor.profile_dir, '-R', profile])
 
         if cmd_info[0] != 0:
-            raise apparmor.AppArmorException(cmd_info[1])
+            raise AppArmorException(cmd_info[1])
 
     def reload_profile(self, profile):
         if not self.do_reload:
             return
 
-        cmd_info = cmd([apparmor.parser, '-I%s' % apparmor.profile_dir, '--base', apparmor.profile_dir, '-r', profile])
-
-        if cmd_info[0] != 0:
-            raise apparmor.AppArmorException(cmd_info[1])
+        apparmor.reload_profile(profile, raise_exc=True)
