@@ -13,17 +13,18 @@
 import os
 import signal
 import subprocess
-import tempfile
 import time
 import unittest
+from tempfile import NamedTemporaryFile
 
-from common_test import AATest, setup_all_loops, setup_aa
 import apparmor.aa as aa
+from common_test import AATest, setup_aa, setup_all_loops
 
 # The location of the aa-notify utility can be overridden by setting
 # the APPARMOR_NOTIFY environment variable; this is useful for running
 # these tests in an installed environment
-aanotify_bin = "../aa-notify"
+aanotify_bin = ["../aa-notify"]
+
 
 # http://www.chiark.greenend.org.uk/ucgi/~cjwatson/blosxom/2009-07-02-python-sigpipe.html
 # This is needed so that the subprocesses that produce endless output
@@ -35,8 +36,8 @@ def subprocess_setup():
 
 
 def cmd(command):
-    '''Try to execute given command (array) and return its stdout, or return
-    a textual error if it failed.'''
+    """Try to execute given command (array) and return its stdout, or return
+    a textual error if it failed."""
 
     try:
         sp = subprocess.Popen(
@@ -48,7 +49,7 @@ def cmd(command):
             preexec_fn=subprocess_setup
         )
     except OSError as e:
-        return [127, str(e)]
+        return 127, str(e)
 
     stdout, stderr = sp.communicate(input)
 
@@ -59,13 +60,13 @@ def cmd(command):
     else:
         out = stdout
 
-    return [sp.returncode, out.decode('utf-8')]
+    return sp.returncode, out.decode('utf-8')
 
 
 class AANotifyTest(AATest):
 
     def AASetup(self):
-        '''Create temporary log file with 30 enties of different age'''
+        """Create temporary log file with 30 enties of different age"""
 
         test_logfile_contents_999_days_old = \
 '''Feb  4 13:40:38 XPS-13-9370 kernel: [128552.834382] audit: type=1400 audit({epoch}:113): apparmor="ALLOWED" operation="exec" profile="libreoffice-soffice" name="/bin/uname" pid=4097 comm="sh" requested_mask="x" denied_mask="x" fsuid=1001 ouid=0 target="libreoffice-soffice//null-/bin/uname"
@@ -112,19 +113,17 @@ Feb  4 13:40:38 XPS-13-9370 kernel: [128552.875891] audit: type=1400 audit({epoc
 Feb  4 13:40:38 XPS-13-9370 kernel: [128552.880347] audit: type=1400 audit({epoch}:122): apparmor="ALLOWED" operation="file_mmap" profile="libreoffice-soffice//null-/usr/bin/file" name="/usr/bin/file" pid=4111 comm="file" requested_mask="rm" denied_mask="rm" fsuid=1001 ouid=0
 '''.format(epoch=round(time.time(), 3))
 
-        handle, self.test_logfile = tempfile.mkstemp(prefix='test-aa-notify-')
-        os.close(handle)
-        handle = open(self.test_logfile, "w+")
-        handle.write(
-            test_logfile_contents_999_days_old +
-            test_logfile_contents_30_days_old +
-            test_logfile_contents_unrelevant_entries +
-            test_logfile_contents_0_seconds_old
-        )
-        handle.close()
+        with NamedTemporaryFile("w+", prefix='test-aa-notify-', delete=False) as temp_file:
+            self.test_logfile = temp_file.name
+            temp_file.write(
+                test_logfile_contents_999_days_old
+                + test_logfile_contents_30_days_old
+                + test_logfile_contents_unrelevant_entries
+                + test_logfile_contents_0_seconds_old
+            )
 
     def AATeardown(self):
-        '''Remove temporary log file after tests ended'''
+        """Remove temporary log file after tests ended"""
 
         if self.test_logfile and os.path.exists(self.test_logfile):
             os.remove(self.test_logfile)
@@ -133,19 +132,19 @@ Feb  4 13:40:38 XPS-13-9370 kernel: [128552.880347] audit: type=1400 audit({epoc
     # before printing help when invoked without arguments (sic!).
     @unittest.skipUnless(os.path.isfile('/var/log/kern.log'), 'Requires kern.log on system')
     def test_no_arguments(self):
-        '''Test using no arguments at all'''
+        """Test using no arguments at all"""
 
         expected_return_code = 0
         expected_output_has = 'usage: aa-notify'
 
-        return_code, output = cmd([aanotify_bin])
+        return_code, output = cmd(aanotify_bin)
         result = 'Got return code %d, expected %d\n' % (return_code, expected_return_code)
         self.assertEqual(expected_return_code, return_code, result + output)
         result = 'Got output "%s", expected "%s"\n' % (output, expected_output_has)
         self.assertIn(expected_output_has, output, result + output)
 
     def test_help_contents(self):
-        '''Test output of help text'''
+        """Test output of help text"""
 
         expected_return_code = 0
         expected_output_1 = \
@@ -173,7 +172,7 @@ Display AppArmor notifications or messages for DENIED entries.
   --debug               debug mode
 '''
 
-        return_code, output = cmd([aanotify_bin, '--help'])
+        return_code, output = cmd(aanotify_bin + ['--help'])
         result = 'Got return code %d, expected %d\n' % (return_code, expected_return_code)
         self.assertEqual(expected_return_code, return_code, result + output)
 
@@ -181,12 +180,12 @@ Display AppArmor notifications or messages for DENIED entries.
         self.assertIn(expected_output_2, output)
 
     def test_entries_since_100_days(self):
-        '''Test showing log entries since 100 days'''
+        """Test showing log entries since 100 days"""
 
         expected_return_code = 0
         expected_output_has = 'AppArmor denials: 20 (since'
 
-        return_code, output = cmd([aanotify_bin, '-f', self.test_logfile, '-s', '100'])
+        return_code, output = cmd(aanotify_bin + ['-f', self.test_logfile, '-s', '100'])
         result = 'Got return code %d, expected %d\n' % (return_code, expected_return_code)
         self.assertEqual(expected_return_code, return_code, result + output)
         result = 'Got output "%s", expected "%s"\n' % (output, expected_output_has)
@@ -194,12 +193,12 @@ Display AppArmor notifications or messages for DENIED entries.
 
     @unittest.skipUnless(os.path.isfile('/var/log/wtmp'), 'Requires wtmp on system')
     def test_entries_since_login(self):
-        '''Test showing log entries since last login'''
+        """Test showing log entries since last login"""
 
         expected_return_code = 0
         expected_output_has = 'AppArmor denials: 10 (since'
 
-        return_code, output = cmd([aanotify_bin, '-f', self.test_logfile, '-l'])
+        return_code, output = cmd(aanotify_bin + ['-f', self.test_logfile, '-l'])
         if "ERROR: Could not find last login" in output:
             self.skipTest('Could not find last login')
         result = 'Got return code %d, expected %d\n' % (return_code, expected_return_code)
@@ -209,7 +208,7 @@ Display AppArmor notifications or messages for DENIED entries.
 
     @unittest.skipUnless(os.path.isfile('/var/log/wtmp'), 'Requires wtmp on system')
     def test_entries_since_login_verbose(self):
-        '''Test showing log entries since last login in verbose mode'''
+        """Test showing log entries since last login in verbose mode"""
 
         expected_return_code = 0
         expected_output_has = \
@@ -275,7 +274,7 @@ Logfile: {logfile}
 
 AppArmor denials: 10 (since'''.format(logfile=self.test_logfile)
 
-        return_code, output = cmd([aanotify_bin, '-f', self.test_logfile, '-l', '-v'])
+        return_code, output = cmd(aanotify_bin + ['-f', self.test_logfile, '-l', '-v'])
         if "ERROR: Could not find last login" in output:
             self.skipTest('Could not find last login')
         result = 'Got return code %d, expected %d\n' % (return_code, expected_return_code)
@@ -289,4 +288,8 @@ setup_all_loops(__name__)
 if __name__ == '__main__':
     if 'APPARMOR_NOTIFY' in os.environ:
         aanotify_bin = os.environ['APPARMOR_NOTIFY']
+
+    if '__AA_CONFDIR' in os.environ:
+        aanotify_bin = aanotify_bin + ['--configdir', os.getenv('__AA_CONFDIR')]
+
     unittest.main(verbosity=1)
